==> haskell-profunctors-5.6.2-213-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.2
visibility:           public
id:                   profunctors-5.6.2-LJDcUqkrAVyKPBPzv6byyz
key:                  profunctors-5.6.2-LJDcUqkrAVyKPBPzv6byyz
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  9fa218900f7b12c7017919b632eb7e75
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.2-LJDcUqkrAVyKPBPzv6byyz
depends:
    base-4.17.2.1 base-orphans-0.9.0-9nADtbFUB1oIgFmn1MRKxW
    bifunctors-5.6-LL970iSyCfRCcLoc6bF757
    comonad-5.0.9-LYxFTGHdzKO2OIgx0Kftcx
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-4vXPhqxWSFrFl2pPpnHCvw
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.6.2-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 profunctors
version:              5.6.2
visibility:           public
id:                   profunctors-5.6.2-EusqY2gdU3dKhCNwHXd7bF
key:                  profunctors-5.6.2-EusqY2gdU3dKhCNwHXd7bF
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/profunctors/
synopsis:             Profunctors
description:          Profunctors.
category:             Control, Categories
abi:                  a66f6b902324268892de248d2f08cccb
exposed:              True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/profunctors-5.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-profunctors
hs-libraries:         HSprofunctors-5.6.2-EusqY2gdU3dKhCNwHXd7bF
depends:
    base-4.17.2.1 base-orphans-0.9.0-D3RoUMPi8EkU4rEEEKnDt
    bifunctors-5.6-7bjFDzshuiBDlYyALqPDBD
    comonad-5.0.9-3OfyuhkjbVOBhstQtOMX9w
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-GSk7CAi1hQl5x29Iyy1OAr
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html:         /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
